/*
 * LogManager.h
 *
 *  Created on: 20/aug/2015
 *      Author: massimo
 */

#pragma once
#include <fstream>
#include <string>
#include <vector>
#include "cdva.h"		// needed to include MatchData declaration

namespace mpeg7cdva
{

/**
 * Format of output logs
 */
enum LogFormat {
	FORMAT_NONE = 0,	///< do not output any data
	FORMAT_CSV =  1,	///< output data in CSV format
	FORMAT_TEXT = 2,	///< output data as free text
	FORMAT_HTML = 4		///< output data in HTML format
};


/**
 * @class LogManager
 * Helper class to produce log files in various formats (csv, text, XML, etc.)
 * @author Massimo Balestri
 * @date 2015
 */
class LogManager {
private:
	double descriptorlength;
	double clip_duration;
	double numframes;
	int myformats;
	size_t numvideos;
	std::string mydatasetpath;
	std::string mydatasetname;
	std::ofstream outcsv;
	std::ofstream outhtml;
	static const char * getModeExtension(int qmode, int refmode);
	static const char * getFormatExtension(LogFormat format);
	static const char * getFormatName(LogFormat format);

public:
	LogManager();	///< constructor

	virtual ~LogManager();	///< destructor

	/**
	 * initialization method used by the Evaluation Framework; do not change.
	 */
	void init(int formats, const std::string & datasetpath, const std::string & datasetname, size_t n_videos, int mode, int refmode = 0);

	/**
	 * set the video duration in seconds.
	 * @param time the time in seconds
	 */
	void setVideoDuration(double time);

	/**
	 * set the number of frames of the video clip.
	 * @param nframes number of frames of the video clip.
	 */
	void setNumFrames(double nframes);

	/**
	 * set the actual descriptor length (in bytes).
	 * @param length the size in bytes of the encoded descriptor.
	 */
	void setDescriptorLength(double length);

	/**
	 * method used by the Evaluation Framework to produce log files; do not change.
	 */
	void printExtractHeader();
	/**
	 * method used by the Evaluation Framework to produce log files; do not change.
	 */
	void printExtractData(int index, const std::string & videoname);

	/**
	 * method used by the Evaluation Framework to produce log files; do not change.
	 */
	void printMatchHeader();
	/**
	 * method used by the Evaluation Framework to produce log files; do not change.
	 */
	void printMatchData(int index, const std::string & queryvideoname, const std::string & refvideoname, const MatchData & matchData);

	/**
	 * method used by the Evaluation Framework to produce log files; do not change.
	 */
	void printRetrievalHeader();
	/**
	 * method used by the Evaluation Framework to produce log files; do not change.
	 */
	void printRetrievalData(int index, const std::string & queryvideoname, const std::vector<MatchData> & retrievalResults);

	void close();
};

}	// end namespace
